import logging
import os
import tempfile

log = logging.getLogger(__name__)


class Config(object):
    SECRET_KEY = os.environ.get('SECRET_KEY') or 'you-will-never-guess'
    JWT_SECRET_KEY = os.environ.get('JWT_SECRET_KEY') or 'super-safe'
    JWT_EXPIRATION_DELTA = 600
    LOGGER_NAME = "flask"
    API_PREFIX = os.environ.get('PORTAL_API_PREFIX', default="/api/v1.0/")


class DevelopmentConfig(Config):
    SQLALCHEMY_DATABASE_URI = 'sqlite://'
    SQLALCHEMY_TRACK_MODIFICATIONS = True
    JWT_EXPIRATION_DELTA = 300
    DEBUG = True


class ProductionConfig(Config):
    DEBUG = False


class TestConfig(Config):
    SQLALCHEMY_TRACK_MODIFICATIONS = False
    TESTING = True
    # SQLALCHEMY_ECHO = True
    KONTR_STORAGE_BASE_DIR = tempfile.mkdtemp()
    KONTR_STORAGE_TEST_FILES_DIR = f"{KONTR_STORAGE_BASE_DIR}/test-files"
    KONTR_STORAGE_WORKSPACE_DIR = f"{KONTR_STORAGE_BASE_DIR}/workspace"
    KONTR_STORAGE_SUBMISSIONS_DIR = f"{KONTR_STORAGE_BASE_DIR}/submissions"


CONFIGURATIONS = dict(
    devel=DevelopmentConfig(),
    test=TestConfig(),
    production=ProductionConfig()
)
