import logging

from portal.database.models import Component
from portal.service import general

log = logging.getLogger(__name__)


def __set_component_data(component: Component, data: dict) -> Component:
    allowed = ['name', 'ip_address', 'secret', 'type', 'notes']
    return general.update_entity(component, data, allowed=allowed)


def create_component(data: dict) -> Component:
    component = Component()
    __set_component_data(component=component, data=data)
    log.info(f"[CREATE] Component({component.id}): {data}")
    return component


def update_component(component: Component, data: dict) -> Component:
    log.info(f"[UPDATE] Component: {component.id}: {data}")
    return __set_component_data(component=component, data=data)


def delete_component(component: Component):
    log.info(f"[DELETE] Component: {component.id} ({component.name})")
    general.delete_entity(component)


def find_all_components():
    return Component.query.all()
