import logging

from flask_emails import Message
from emails.template import JinjaTemplate as T

log = logging.getLogger(__name__)


class EmailMessage(object):
    def __init__(self, subject, body, **kwargs):
        self._subject = T(subject)
        self._body = T(body)
        self._params = kwargs

    @property
    def subject(self):
        return self._subject

    @property
    def body(self):
        return self._body

    def create_message(self):
        return Message(subject=self.subject, html=self.body, **self._params)


USERS = dict(
    created=EmailMessage(
        subject="User created: {{username}}",
        message="User {{username}} has been created"
    ),
    deleted=EmailMessage(
        subject="User deleted: {{username}}",
        message="User {{username}} has been deleted"
    ),
    updated=None
)

COURSES = dict(
    created=None,
    deleted=None,
    updated=None
)

PROJECTS = dict(
    created=None,
    deleted=None,
    updated=None
)

MESSAGES = dict(
    users=USERS,
    courses=COURSES,
    projects=PROJECTS,
)


def get_email_message(collection, action):
    return MESSAGES[collection][action]
